==> nextcloud-27.1.11.tgz: nextcloud/apps/firstrunwizard/l10n/zh_TW.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "首次使用精靈",
    "Add your profile information! For example your email is needed to receive notifications." : "加入您的個人資訊吧！舉例來說，我們需要您的電子郵件地址才能在您需要時收到通知。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的電子郵件地址才能在您需要時收到通知並重設您的密碼。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭照和全名可以讓您在各種功能的介面當中快速被找到。",
    "Add your profile information! Set a full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入全名可以讓您在各種功能的介面當中快速被找到。",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭照可以讓您在各種功能的介面當中快速被找到。",
    "App recommendation: Nextcloud Calendar" : "推薦功能: Nextcloud Calendar",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步。",
    "App recommendation: Nextcloud Contacts" : "推薦功能: Nextcloud Conracts",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯絡資訊整合在一處，且不洩漏他們的個人資訊。",
    "App recommendation: Nextcloud Mail" : "推薦功能: Nextcloud Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案總管、通訊錄、行事曆完美整合。",
    "App recommendation: Tasks" : "推薦功能: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步工作項目並在線上進行編輯。",
    "App recommendation: Deck" : "推薦功能: Deck",
    "Kanban style organization for personal planning and team projects." : "看板風格的組織，用於個人計畫與團隊專案。",
    "App recommendation: Forms" : "推薦功能: Forms",
    "Simple surveys and questionnaires, self-hosted" : "自託管的簡單調查和問卷",
    "App recommendation: Recognize" : "推薦功能: Recognize",
    "Smart media tagging for Nextcloud" : "Nextcloud 的智慧型媒體標記",
    "App recommendation: Group folders" : "推薦功能: Group folders",
    "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
    "About & What's new" : "關於與新功能",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的歡迎及介紹精靈",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此應用程式會在使用者第一次登入到 Nextcloud 時會顯示一個彈出式視窗。此視窗會顯示歡迎 Nextcloud 新使用者的訊息，並包含到標準桌面用戶端的連結、Android 應用程式以及 iOS 應用程式。此視窗也會顯示透過 WebDAV 存取 Nextcloud 的連結。首次執行精靈隨時可以在設定選單中的「關於」連結再次開啟。\n首次執行精靈可以自訂以符合設計目標，或是變更連結與訊息。檢視佈景主題文件以建立對應的佈景主題，變更此精靈的外觀與感覺相當簡單。更多資訊可在首次執行精靈以及佈景主題的文件中看到。",
    "Download on Apple app store" : "在 Apple 應用程式商店下載",
    "Download on Google play store" : "在 Google Play 商店下載",
    "Go to previous page" : "到前一頁",
    "Close" : "關閉",
    "More about Nextcloud" : "更多關於 Nextcloud 的資訊",
    "Explore more apps ↗" : "探索更多應用程式 ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "使用數百個社群開發的應用程式擴充 Nextcloud 的功能。",
    "Get involved! ↗" : "參與其中！ ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成為協助建立、設計、翻譯與推廣 Nextcloud 的社群一分子！",
    "Need help? ↗" : "需要協助？ ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "透過管理員、使用者或開發者文件了解關於 Nextcloud 設定的更多資訊。",
    "For large organisations ↗" : "對於大型組織 ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "取得適用於進階安全性及法律遵循非常重要的任務關鍵型環境的 Nextcloud Enterprise。",
    "This Nextcloud is on version {version}" : "此 Nextcloud 版本為 {version}",
    "Seamless integration with your devices." : "與您的裝置無縫整合。",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面與行動裝置應用程式在您的裝置間同步檔案，並連結您的日曆與通訊錄。",
    "Desktop app ↗" : "桌面應用程式 ↗",
    "Download For Windows, Mac OS and Linux." : "下載適用於 Windows、macOS 與 Linux 的版本",
    "Calendar and contacts ↗" : "日曆與通訊錄 ↗",
    "Connect your calendar and contacts with your devices." : "將您的日曆與通訊錄和您的裝置連結起來。",
    "Introducing Nextcloud Hub {version}" : "Nextcloud Hub {version} 簡介",
    "Welcome to {cloudName}!" : "歡迎使用 {cloudName}！",
    "A collaboration platform that puts you in control" : "一個您可掌控的協作平台",
    "Privacy" : "隱私",
    "Host your data and files where you decide." : "在您決定的位置存放您的資料與檔案。",
    "Productivity" : "生產力",
    "Collaborate and communicate across any platform." : "跨任何平台協作與溝通。",
    "Interoperability" : "互通性",
    "Import and export anything you want with open standards." : "使用開放標準匯入與匯出任何您想要的內容。",
    "Community" : "社群",
    "Enjoy constant improvements from a thriving open-source community." : "享受來自蓬勃發展的開放原始碼社群的不斷改善",
    "Find out more on the blog" : "在部落格上尋找更多資訊",
    "Read the Nextcloud Hub {version} blog" : "閱讀 Nextcloud Hub {version} 部落格",
    "Share your opinion about Nextcloud Hub {version}" : "分享您對 Nextcloud Hub {version} 的看法",
    "Share via email" : "透過電郵分享",
    "Share on {socialMedia}" : "在 {socialMedia} 上分享",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} 釋出",
    "Read more about it on the Nextcloud Hub {version} blog" : "在 Nextcloud Hub {version} 部落格上了解更多相關資訊",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version} 中的新增功能",
    "Assistant: chat summaries, Mail reply suggestions, answers based on your data, and more" : "小幫手：聊天摘要、郵件回覆建議、以您的資料為基礎的答案等",
    "Interactive previews for files, folders, boards and events" : "檔案、資料夾、看板與事件的互動式預覽",
    "Federated chat and message editing in Talk" : "Talk 中的聯合聊天與訊息編輯",
    "Mini-apps based on Tables" : "以表格為基礎的小應用程式",
    "Public Collectives sharing, previews and QR-codes" : "公開收藏庫分享、預覽與 QR code",
    "Manage your team resources like a pro with Nextcloud Teams" : "使用 Nextcloud Teams 像專業人士一樣管理您的團隊資源",
    "Forms: automatically sync with a spreadsheet" : "表單：自動與試算表同步",
    "Get to know the new features of Hub 8" : "了解 Hub 8 的新功能",
    "What's new?" : "有什麼新鮮事？",
    "Nextcloud on all your devices" : "您所有裝置上的 Nextcloud",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "更多",
    "Share on social media" : "在社群媒體上分享",
    "Get started!" : "開始！",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和行動裝置用戶端。",
    "Desktop client" : "桌面用戶端",
    "Android app on Google Play Store" : "Google Play 商店中的 Android 應用程式",
    "Android app on F-Droid" : "F-Droid 中的 Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "使用<a href=\"%s\">應用程式密碼</a>設定同步用戶端。這樣，您可以確保遺失裝置時撤銷該裝置的存取權。",
    "Connect other apps to %s" : "連結其他應用程式到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了行動裝置應用程式及桌面用戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟體到 %s。",
    "Connect your calendar" : "連結您的日曆",
    "Connect your contacts" : "連結您的聯絡人",
    "Access files via WebDAV" : "透過 WebDAV 存取檔案",
    "Download macOS/iOS configuration profile" : "下載 macOS/iOS 描述檔",
    "Server address" : "伺服器位址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此連結將您的應用程式與桌面用戶端連結到此伺服器:",
    "Copy link" : "複製連結",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按 ⌘-C 以複製。",
    "Press Ctrl-C to copy." : "請按 Ctrl-C 以複製。",
    "About" : "關於",
    "Start using {cloudName}" : "開始使用 {cloudName}",
    "Extend your cloud" : "延展您的雲端",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "在 Nextcloud 應用程式商店中尋找超過一百個應用程式來客製化您的雲端:",
    "Groupware apps like Calendar, Contacts, Mail" : "協作應用程式，像是日曆、聯絡人、電子郵件",
    "Communication with Nextcloud Talk" : "透過 Nextcloud Talk 傳送訊息或通話",
    "Collaboration apps for document editing" : "用於文件編輯的協作應用程式",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "按權與驗證功能，如兩階段驗證、SSO 與勒索軟體保護",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "許多其他功能，如音樂播放程式、密碼管理員、看板應用程式、下載管理程式或 Markdown 編輯器等",
    "Browse the App Store" : "瀏覽應用程式商店",
    "Stay in sync" : "保持同步",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud 讓您無論身在何處都可以存取您的檔案。",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "我們簡單易用的桌面和行動用戶端在各大平台上面免費提供！",
    "Connect your desktop apps to %s" : "將您的桌面應用程式連結到 %s",
    "Get help" : "取得協助",
    "Start contributing" : "開始貢獻",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想要取得 Nextcloud 特定的改進嗎？您有找到問題嗎？你想要幫忙翻譯，推動或是寫 Nextcloud 文件嗎？",
    "Become part of the Community" : "成為社群的一分子",
    "Enterprise support" : "企業級支援",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "若您在安全性與法遵非常重要的關鍵工作環境中執行 Nextcloud，您可能會需要 Nextcloud Enterprise。",
    "Learn more about Nextcloud Enterprise" : "取得更多關於 Nextcloud Enterprise 的資訊",
    "Get more information" : "取得更多資訊",
    "The Nextcloud documentation for home users:" : "家庭使用者的 Nextcloud 文件:",
    "User manual" : "使用者手冊",
    "Admin manual" : "管理者手冊",
    "Developer manual" : "開發人員手冊",
    "You can also ask for help in our community support channels:" : "您也可以在我們的社群支援頻道尋求協助:",
    "the Nextcloud forums" : "Nextcloud 論壇",
    "A safe home for all your data" : "您資料的安全屋",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 將您的資料置於您觸手可及之處且在您掌控之下。將您的文件、日曆、聯絡人與照片儲存在您的公司、家中、我們的其中一個提供商或是您所知的資料中心的伺服器上。",
    "Host your data and files where you decide" : "在您決定的位置存放您的資料與檔案",
    "Open standards and interoperability" : "開放標準與互操作性",
    "100%% open source & community-focused" : "100%% 開放原始碼及以社群為中心",
    "Learn more about %s" : "了解更多關於%s",
    "This Nextcloud is on version %s" : "此 Nextcloud 版本為 %s",
    "Close dialog" : "關閉對話方塊",
    "This Nextcloud is on version " : "此 Nextcloud 版本為"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/firstrunwizard/l10n/zh_TW.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "首次使用精靈",
    "Add your profile information! For example your email is needed to receive notifications." : "加入您的個人資訊吧！舉例來說，我們需要您的電子郵件地址才能在您需要時收到通知。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的電子郵件地址才能在您需要時收到通知並重設您的密碼。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭照和全名可以讓您在各種功能的介面當中快速被找到。",
    "Add your profile information! Set a full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入全名可以讓您在各種功能的介面當中快速被找到。",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭照可以讓您在各種功能的介面當中快速被找到。",
    "App recommendation: Nextcloud Calendar" : "推薦功能: Nextcloud Calendar",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步。",
    "App recommendation: Nextcloud Contacts" : "推薦功能: Nextcloud Conracts",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯絡資訊整合在一處，且不洩漏他們的個人資訊。",
    "App recommendation: Nextcloud Mail" : "推薦功能: Nextcloud Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案總管、通訊錄、行事曆完美整合。",
    "App recommendation: Tasks" : "推薦功能: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步工作項目並在線上進行編輯。",
    "App recommendation: Deck" : "推薦功能: Deck",
    "Kanban style organization for personal planning and team projects." : "看板風格的組織，用於個人計畫與團隊專案。",
    "App recommendation: Forms" : "推薦功能: Forms",
    "Simple surveys and questionnaires, self-hosted" : "自託管的簡單調查和問卷",
    "App recommendation: Recognize" : "推薦功能: Recognize",
    "Smart media tagging for Nextcloud" : "Nextcloud 的智慧型媒體標記",
    "App recommendation: Group folders" : "推薦功能: Group folders",
    "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
    "Connect your calendar" : "連結您的日曆",
    "Connect your contacts" : "連結您的聯絡人",
    "Access files via WebDAV" : "透過 WebDAV 存取檔案",
    "Download macOS/iOS configuration profile" : "下載 macOS/iOS 描述檔",
    "Desktop client" : "桌面用戶端",
    "Android app on Google Play Store" : "Google Play 商店中的 Android 應用程式",
    "Android app on F-Droid" : "F-Droid 中的 Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "About & What's new" : "關於與新功能",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的歡迎及介紹精靈",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此應用程式會在使用者第一次登入到 Nextcloud 時會顯示一個彈出式視窗。此視窗會顯示歡迎 Nextcloud 新使用者的訊息，並包含到標準桌面用戶端的連結、Android 應用程式以及 iOS 應用程式。此視窗也會顯示透過 WebDAV 存取 Nextcloud 的連結。首次執行精靈隨時可以在設定選單中的「關於」連結再次開啟。\n首次執行精靈可以自訂以符合設計目標，或是變更連結與訊息。檢視佈景主題文件以建立對應的佈景主題，變更此精靈的外觀與感覺相當簡單。更多資訊可在首次執行精靈以及佈景主題的文件中看到。",
    "Download on Apple app store" : "在 Apple 應用程式商店下載",
    "Download on Google play store" : "在 Google Play 商店下載",
    "Go to previous page" : "到前一頁",
    "Close" : "關閉",
    "More about Nextcloud" : "更多關於 Nextcloud 的資訊",
    "Explore more apps ↗" : "探索更多應用程式 ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "使用數百個社群開發的應用程式擴充 Nextcloud 的功能。",
    "Get involved! ↗" : "參與其中！ ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成為協助建立、設計、翻譯與推廣 Nextcloud 的社群一分子！",
    "Need help? ↗" : "需要協助？ ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "透過管理員、使用者或開發者文件了解關於 Nextcloud 設定的更多資訊。",
    "For large organisations ↗" : "對於大型組織 ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "取得適用於進階安全性及法律遵循非常重要的任務關鍵型環境的 Nextcloud Enterprise。",
    "This Nextcloud is on version {version}" : "此 Nextcloud 版本為 {version}",
    "Seamless integration with your devices." : "與您的裝置無縫整合。",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面與行動裝置應用程式在您的裝置間同步檔案，並連結您的日曆與通訊錄。",
    "Desktop app ↗" : "桌面應用程式 ↗",
    "Download For Windows, Mac OS and Linux." : "下載適用於 Windows、macOS 與 Linux 的版本",
    "Calendar and contacts ↗" : "日曆與通訊錄 ↗",
    "Connect your calendar and contacts with your devices." : "將您的日曆與通訊錄和您的裝置連結起來。",
    "Introducing Nextcloud Hub {version}" : "Nextcloud Hub {version} 簡介",
    "Welcome to {cloudName}!" : "歡迎使用 {cloudName}！",
    "A collaboration platform that puts you in control" : "一個您可掌控的協作平台",
    "Privacy" : "隱私",
    "Host your data and files where you decide." : "在您決定的位置存放您的資料與檔案。",
    "Productivity" : "生產力",
    "Collaborate and communicate across any platform." : "跨任何平台協作與溝通。",
    "Interoperability" : "互通性",
    "Import and export anything you want with open standards." : "使用開放標準匯入與匯出任何您想要的內容。",
    "Community" : "社群",
    "Enjoy constant improvements from a thriving open-source community." : "享受來自蓬勃發展的開放原始碼社群的不斷改善",
    "Find out more on the blog" : "在部落格上尋找更多資訊",
    "Read the Nextcloud Hub {version} blog" : "閱讀 Nextcloud Hub {version} 部落格",
    "Share your opinion about Nextcloud Hub {version}" : "分享您對 Nextcloud Hub {version} 的看法",
    "Share via email" : "透過電郵分享",
    "Share on {socialMedia}" : "在 {socialMedia} 上分享",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} 釋出",
    "Read more about it on the Nextcloud Hub {version} blog" : "在 Nextcloud Hub {version} 部落格上了解更多相關資訊",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version} 中的新增功能",
    "Connect other apps to {productName}" : "將其他應用程式連結到 {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "除了行動裝置應用程式及桌面用戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟體到 {productName}。",
    "Apps to connect to {productName}" : "要連結到 {productName} 的應用程式",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和行動裝置用戶端。",
    "App for syncing" : "用於同步的應用程式",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "使用{linkStart}應用程式密碼{linkEnd}設定同步用戶端。這樣，您可以確保遺失裝置時撤銷該裝置的存取權。",
    "Server address" : "伺服器位址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此連結將您的應用程式與桌面用戶端連結到此伺服器:",
    "URL copied" : "已複製 URL",
    "Could not copy the URL, please copy manually" : "無法複製 URL，請手動複製",
    "Federated collaboration: file sharing, messaging, calls" : "聯合協作：檔案分享、訊息傳遞、通話",
    "Nextcloud Project" : "Nextcloud 專案",
    "Nextcloud Whiteboard" : "Nextcloud 白板",
    "Workflow Engine" : "工作流程引擎",
    "Safer and swifter mail" : "更安全且更迅速的電子郵件",
    "Public Collectives sharing, previews and QR-codes" : "公開收藏庫分享、預覽與 QR code",
    "Office and PDF templates" : "Office 與 PDF 範本",
    "Chat mode for Nextcloud Assistant" : "Nextcloud 小幫手的聊天模式",
    "Get to know the new features of Hub 9" : "了解 Hub 9 的新功能",
    "What's new?" : "有什麼新鮮事？",
    "Nextcloud on all your devices" : "您所有裝置上的 Nextcloud",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "更多",
    "Share on social media" : "在社群媒體上分享",
    "Get started!" : "開始！",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按 ⌘-C 以複製。",
    "Press Ctrl-C to copy." : "請按 Ctrl-C 以複製。",
    "About" : "關於",
    "Close dialog" : "關閉對話方塊",
    "This Nextcloud is on version " : "此 Nextcloud 版本為",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和行動裝置用戶端。",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "使用<a href=\"%s\">應用程式密碼</a>設定同步用戶端。這樣，您可以確保遺失裝置時撤銷該裝置的存取權。",
    "Connect other apps to %s" : "連結其他應用程式到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了行動裝置應用程式及桌面用戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟體到 %s。",
    "Copy link" : "複製連結",
    "Assistant: chat summaries, Mail reply suggestions, answers based on your data, and more" : "小幫手：聊天摘要、郵件回覆建議、以您的資料為基礎的答案等",
    "Interactive previews for files, folders, boards and events" : "檔案、資料夾、看板與事件的互動式預覽",
    "Federated chat and message editing in Talk" : "Talk 中的聯合聊天與訊息編輯",
    "Mini-apps based on Tables" : "以表格為基礎的小應用程式",
    "Manage your team resources like a pro with Nextcloud Teams" : "使用 Nextcloud Teams 像專業人士一樣管理您的團隊資源",
    "Forms: automatically sync with a spreadsheet" : "表單：自動與試算表同步",
    "Get to know the new features of Hub 8" : "了解 Hub 8 的新功能"
},
"nplurals=1; plural=0;");
